==> visual-third-party-1.0-sources.jar: com/tenqube/visual_third/core/OneLoader.java <==
package com.tenqube.visual_third.core;

import android.annotation.SuppressLint;
import android.content.Context;
import android.location.Location;
import android.os.Bundle;
import android.os.Handler;
import android.os.Message;

import com.tenqube.visual_third.model.Company;
import com.tenqube.visual_third.model.TranCompany;
import com.tenqube.visual_third.model.TransactionPopupInfo;
import com.tenqube.visual_third.ui.TransactionPopupActivity;

import java.util.ArrayList;

import tenqube.parser.core.ParserService;
import tenqube.parser.model.ParserResult;
import tenqube.parser.model.ResultCode;
import tenqube.parser.model.SMS;
import tenqube.parser.model.Transaction;

import static com.tenqube.visual_third.Constants.SAMSUNG_PAY;
import static com.tenqube.visual_third.util.Utils.shouldParsing;
import static tenqube.parser.core.ParserService.mIsDebug;
import static tenqube.parser.util.LogUtil.LOGI;

/**
 * SMS or MMS or NOTI 수신시 실행
 *
 */
class OneLoader {

    private static final String TAG = OneLoader.class.getSimpleName();
    private static OneLoader mInstance = null;
    private Context mContext;
    private final FusedLocationManager fusedLocationManager;
    private ParserService parserService;
    private int mServerCnt = 0;
    private VisualApi api;

    public static OneLoader getInstance(Context context) {

        synchronized (OneLoader.class) {
            if (mInstance == null) {
                mInstance = new OneLoader(context.getApplicationContext());
            }
        }
        return mInstance;
    }


    private OneLoader(Context context) {
        this.mContext = context;
        this.fusedLocationManager = FusedLocationManager.getInstance(context);
        this.parserService = ParserService.getInstance(context);
        this.api = VisualApi.getInstance(context);
    }

    @SuppressLint("HandlerLeak")
    private final Handler mHandler = new Handler() {
        @Override
        public void handleMessage(Message msg) {
            if(msg.what == 200) {
                Bundle bundle = msg.getData();
                if(bundle != null) {
                    TransactionPopupInfo transactionPopupInfo = new TransactionPopupInfo((Transaction)bundle.getSerializable("transaction"),
                            (Company)bundle.getSerializable("company"));

                    TransactionPopupActivity.startActivity(mContext, (transactionPopupInfo));
                }

            }
        }
    };


    /**
     * ParserResult의 코드에따라서 파싱된내역 서버전송, 파싱룰 동기화 안잡힌거 전송으로 분기
     * @param sms 문자 데이터
     */
    public synchronized void doParsing(final SMS sms) {

        new Thread(new Runnable() {
            @Override
            public void run() {

                LOGI(TAG, "doParsing" + sms.toString(), true);

                fusedLocationManager.loadLastLocation();

                // 파싱
                ParserResult parserResult = parserService.parse(sms);

                // 실패하고 삼성페이인경우 title 로 파싱
                if(parserResult.resultCode != ResultCode.SEND_TO_SERVER &&
                        SAMSUNG_PAY.equals(sms.sender)) {

                    sms.fullSms = sms.title;
                    parserResult = parserService.parse(sms);

                }

                // 파싱 결과에 따른 분기
                LOGI(TAG, "parserResult" + (parserResult.resultCode) + ResultCode.stringValueOf(parserResult.resultCode), true);

                switch(parserResult.resultCode) {
                    case ResultCode.NEED_TO_SYNC_PARSING_RULE:
                        syncParsingRule();
                        break;

                    case ResultCode.NEED_TO_SYNC_PARSING_RULE_NO_SENDER:
                        if(shouldParsing(sms.fullSms)) syncParsingRuleAndNoSender();
                        break;

                    case ResultCode.NEED_TO_SEND_TO_SERVER:
                        break;

                    case ResultCode.SEND_TO_SERVER:
                        parsedSMS(parserResult.transactions);
                        break;

                }

            }
        }).start();


    }

    private void syncParsingRuleAndNoSender() {
        mServerCnt++;
        if(mServerCnt == 5) {
            mServerCnt = 0;
            syncParsingRule();
        }
    }

    /**
     * 파싱된 경우
     * 결과값 저장 및 파싱된 내역 구글 캘린더 알림 노출 등 기존 로직 처리
     * @param transactions 파싱된 내역
     */
    private void parsedSMS(ArrayList<Transaction> transactions) {

        try {
            Transaction currentTran = popCurrentTran(transactions);
            // 위치정보 추가

            if(currentTran != null) {
                addLocationInfo(currentTran);
                transactions.add(currentTran);
            }

            // 서버 전송
            TranCompany tranCompany = sendToServer(transactions);

            // 팝업 띄움. current Tran && 중복 아닌경
            if(currentTran != null && currentTran.isDuplicate == 0)
                checkCurrentTranInfo(tranCompany, currentTran);


        } catch (Exception e) {
            e.printStackTrace();
        }

    }

    private Transaction popCurrentTran(ArrayList<Transaction> transactions) {

        int index = -1;
        for (int i = 0 ; i < transactions.size() ; i ++ ) {
            Transaction transaction = transactions.get(i);

            if (transaction.isCurrentTran) {
                index = i;
                break;
            }
        }

        if(index != -1) {
            Transaction transaction = transactions.get(index);
            transactions.remove(index);
            return transaction;
        }

        return null;
    }

    private void addLocationInfo(Transaction currentTran) {
        Location location = fusedLocationManager.getLocation();
        if (location != null) {
            currentTran.spentLatitude = location.getLatitude();
            currentTran.spentLongitude = location.getLongitude();
        } else {
            currentTran.spentLatitude = -1;
            currentTran.spentLongitude = -1;
        }
    }



    /**
     * 파싱된 결과 서버 전송
     * @param transactions 파싱된 데이터
     */
    private TranCompany sendToServer(final ArrayList<Transaction> transactions) {

        //서버전송
        return api.sendToServerTransactionsWithSync(transactions);
    }

    /**
     * 파싱 결과 팝업
     */
    private void checkCurrentTranInfo(final TranCompany tranCompany, Transaction currentTran) {

        boolean isMatched = false;
        if(tranCompany != null) {
            for(Company company : tranCompany.getCompanys()) {
                if(company.getIdentifier() == currentTran.identifier) {

                    TransactionPopupInfo transactionPopupInfo = new TransactionPopupInfo(currentTran,
                            company);
                    TransactionPopupActivity.startActivity(mContext, (transactionPopupInfo));
                    isMatched = true;
                    break;
                }
            }

            // 테스트를 위해 디버그 모드인경우 첫번째 아이템 리턴
            if(!isMatched && mIsDebug && !tranCompany.getCompanys().isEmpty()) {
                TransactionPopupInfo transactionPopupInfo = new TransactionPopupInfo(currentTran,
                        tranCompany.getCompanys().get(0));
                TransactionPopupActivity.startActivity(mContext, (transactionPopupInfo));

            }
        }

    }

    /**
     * 파싱룰 서버 동기화 필요
     */
    private void syncParsingRule() {
        parserService.syncParsingRule(api.syncParsingRule());
    }


}

==> visual-third-party-1.3-sources.jar: com/tenqube/visual_third/core/OneLoader.java <==
package com.tenqube.visual_third.core;

import android.annotation.SuppressLint;
import android.content.Context;
import android.location.Location;
import android.os.Bundle;
import android.os.Handler;
import android.os.Message;

import com.tenqube.visual_third.model.Company;
import com.tenqube.visual_third.model.TranCompany;
import com.tenqube.visual_third.model.TransactionPopupInfo;
import com.tenqube.visual_third.ui.TransactionPopupActivity;

import java.util.ArrayList;

import retrofit2.Call;
import retrofit2.Callback;
import retrofit2.Response;
import tenqube.parser.core.ParserService;
import tenqube.parser.model.ParserResult;
import tenqube.parser.model.ResultCode;
import tenqube.parser.model.SMS;
import tenqube.parser.model.Transaction;

import static com.tenqube.visual_third.Constants.SAMSUNG_PAY;
import static com.tenqube.visual_third.util.Utils.shouldParsing;
import static tenqube.parser.core.ParserService.mIsDebug;
import static tenqube.parser.util.LogUtil.LOGI;

/**
 * SMS or MMS or NOTI 수신시 실행
 *
 */
class OneLoader {

    private static final String TAG = OneLoader.class.getSimpleName();
    private static OneLoader mInstance = null;
    private Context mContext;
    private final FusedLocationManager fusedLocationManager;
    private ParserService parserService;
    private int mServerCnt = 0;
    private VisualApi api;

    public static OneLoader getInstance(Context context) {

        synchronized (OneLoader.class) {
            if (mInstance == null) {
                mInstance = new OneLoader(context.getApplicationContext());
            }
        }
        return mInstance;
    }


    private OneLoader(Context context) {
        this.mContext = context;
        this.fusedLocationManager = FusedLocationManager.getInstance(context);
        this.parserService = ParserService.getInstance(context);
        this.api = VisualApi.getInstance(context);
    }

    @SuppressLint("HandlerLeak")
    private final Handler mHandler = new Handler() {
        @Override
        public void handleMessage(Message msg) {
            if(msg.what == 200) {
                Bundle bundle = msg.getData();
                if(bundle != null) {
                    TransactionPopupInfo transactionPopupInfo = new TransactionPopupInfo((Transaction)bundle.getSerializable("transaction"),
                            (Company)bundle.getSerializable("company"));

                    TransactionPopupActivity.startActivity(mContext, (transactionPopupInfo));
                }

            }
        }
    };


    /**
     * ParserResult의 코드에따라서 파싱된내역 서버전송, 파싱룰 동기화 안잡힌거 전송으로 분기
     * @param sms 문자 데이터
     */
    public synchronized void doParsing(final SMS sms) {

        new Thread(new Runnable() {
            @Override
            public void run() {

                LOGI(TAG, "doParsing" + sms.toString(), true);

                fusedLocationManager.loadLastLocation();

                // 파싱
                ParserResult parserResult = parserService.parse(sms);

                // 실패하고 삼성페이인경우 title 로 파싱
                if(parserResult.resultCode != ResultCode.SEND_TO_SERVER &&
                        SAMSUNG_PAY.equals(sms.sender)) {

                    sms.fullSms = sms.title;
                    parserResult = parserService.parse(sms);

                }

                // 파싱 결과에 따른 분기
                LOGI(TAG, "parserResult" + (parserResult.resultCode) + ResultCode.stringValueOf(parserResult.resultCode), true);

                switch(parserResult.resultCode) {
                    case ResultCode.NEED_TO_SYNC_PARSING_RULE:
                        syncParsingRule();
                        break;

                    case ResultCode.NEED_TO_SYNC_PARSING_RULE_NO_SENDER:
                        if(shouldParsing(sms.fullSms)) syncParsingRuleAndNoSender();
                        break;

                    case ResultCode.NEED_TO_SEND_TO_SERVER:
                        break;

                    case ResultCode.SEND_TO_SERVER:
                        parsedSMS(parserResult.transactions);
                        break;

                }

            }
        }).start();


    }

    private void syncParsingRuleAndNoSender() {
        mServerCnt++;
        if(mServerCnt == 5) {
            mServerCnt = 0;
            syncParsingRule();
        }
    }

    /**
     * 파싱된 경우
     * 결과값 저장 및 파싱된 내역 구글 캘린더 알림 노출 등 기존 로직 처리
     * @param transactions 파싱된 내역
     */
    private void parsedSMS(ArrayList<Transaction> transactions) {

        try {
            Transaction currentTran = popCurrentTran(transactions);
            // 위치정보 추가

            if(currentTran != null) {
                addLocationInfo(currentTran);
            }

            if(!transactions.isEmpty())
                api.searchCompany(transactions, new Callback<TranCompany>() {
                    @Override
                    public void onResponse(Call<TranCompany> call, Response<TranCompany> response) {

                    }

                    @Override
                    public void onFailure(Call<TranCompany> call, Throwable t) {

                    }
                });


            // 서버 전송
            TranCompany tranCompany = api.searchCompany(currentTran);

            // 팝업 띄움. current Tran && 중복 아닌경
            if(currentTran != null && currentTran.isDuplicate == 0)
                checkCurrentTranInfo(tranCompany, currentTran);


        } catch (Exception e) {
            e.printStackTrace();
        }

    }

    private Transaction popCurrentTran(ArrayList<Transaction> transactions) {

        int index = -1;
        for (int i = 0 ; i < transactions.size() ; i ++ ) {
            Transaction transaction = transactions.get(i);

            if (transaction.isCurrentTran) {
                index = i;
                break;
            }
        }

        if(index != -1) {
            Transaction transaction = transactions.get(index);
            transactions.remove(index);
            return transaction;
        }

        return null;
    }

    private void addLocationInfo(Transaction currentTran) {
        Location location = fusedLocationManager.getLocation();
        if (location != null) {
            currentTran.spentLatitude = location.getLatitude();
            currentTran.spentLongitude = location.getLongitude();
        } else {
            currentTran.spentLatitude = -1;
            currentTran.spentLongitude = -1;
        }
    }



    /**
     * 파싱 결과 팝업
     */
    private void checkCurrentTranInfo(final TranCompany tranCompany, Transaction currentTran) {

        boolean isMatched = false;
        if(tranCompany != null) {
            for(Company company : tranCompany.getCompanys()) {
                if(company.getIdentifier() == currentTran.identifier) {

                    TransactionPopupInfo transactionPopupInfo = new TransactionPopupInfo(currentTran,
                            company);
                    TransactionPopupActivity.startActivity(mContext, (transactionPopupInfo));
                    isMatched = true;
                    break;
                }
            }

            // 테스트를 위해 디버그 모드인경우 첫번째 아이템 리턴
            if(!isMatched && mIsDebug && !tranCompany.getCompanys().isEmpty()) {
                TransactionPopupInfo transactionPopupInfo = new TransactionPopupInfo(currentTran,
                        tranCompany.getCompanys().get(0));
                TransactionPopupActivity.startActivity(mContext, (transactionPopupInfo));

            }
        }

    }

    /**
     * 파싱룰 서버 동기화 필요
     */
    private void syncParsingRule() {
        parserService.syncParsingRule(api.syncParsingRule());
    }


}
